aboutsummaryrefslogtreecommitdiffstats
path: root/tools/qmlprofiler/profiledata.h
diff options
context:
space:
mode:
Diffstat (limited to 'tools/qmlprofiler/profiledata.h')
-rw-r--r--tools/qmlprofiler/profiledata.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/tools/qmlprofiler/profiledata.h b/tools/qmlprofiler/profiledata.h
index eaa2127f4a..f5d726916c 100644
--- a/tools/qmlprofiler/profiledata.h
+++ b/tools/qmlprofiler/profiledata.h
@@ -3,7 +3,7 @@
** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/
**
** This file is part of the QtDeclarative module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** GNU Lesser General Public License Usage
@@ -42,16 +42,16 @@
#ifndef PROFILEDATA_H
#define PROFILEDATA_H
-#include <QtDeclarative/private/qdeclarativeprofilerservice_p.h>
+#include <QtQml/private/qqmlprofilerservice_p.h>
#include <QtCore/QObject>
#include <QtCore/QHash>
-struct DeclarativeEvent;
+struct QmlEvent;
struct V8Event;
-typedef QHash<QString, DeclarativeEvent *> DeclarativeEventHash;
-typedef QList<DeclarativeEvent *> DeclarativeEvents;
+typedef QHash<QString, QmlEvent *> QmlEventHash;
+typedef QList<QmlEvent *> QmlEvents;
typedef QList<V8Event *> V8Events;
struct EventLocation
@@ -64,32 +64,32 @@ struct EventLocation
int column;
};
-struct DeclarativeEventSub {
- DeclarativeEventSub(DeclarativeEvent *from)
+struct QmlEventSub {
+ QmlEventSub(QmlEvent *from)
: reference(from), duration(0), calls(0), inLoopPath(false)
{}
- DeclarativeEventSub(DeclarativeEventSub *from)
+ QmlEventSub(QmlEventSub *from)
: reference(from->reference), duration(from->duration),
calls(from->calls), inLoopPath(from->inLoopPath)
{}
- DeclarativeEvent *reference;
+ QmlEvent *reference;
qint64 duration;
qint64 calls;
bool inLoopPath;
};
-struct DeclarativeEvent
+struct QmlEvent
{
- DeclarativeEvent();
- ~DeclarativeEvent();
+ QmlEvent();
+ ~QmlEvent();
QString displayname;
QString eventHashStr;
QString details;
EventLocation location;
- QDeclarativeProfilerService::RangeType eventType;
- QHash <QString, DeclarativeEventSub *> parentHash;
- QHash <QString, DeclarativeEventSub *> childrenHash;
+ QQmlProfilerService::RangeType eventType;
+ QHash <QString, QmlEventSub *> parentHash;
+ QHash <QString, QmlEventSub *> childrenHash;
qint64 duration;
qint64 calls;
qint64 minTime;
@@ -100,7 +100,7 @@ struct DeclarativeEvent
int eventId;
bool isBindingLoop;
- DeclarativeEvent &operator=(const DeclarativeEvent &ref);
+ QmlEvent &operator=(const QmlEvent &ref);
};
struct V8EventSub {
@@ -143,8 +143,8 @@ public:
explicit ProfileData(QObject *parent = 0);
~ProfileData();
- DeclarativeEvents getDeclarativeEvents() const;
- DeclarativeEvent *declarativeEvent(int eventId) const;
+ QmlEvents getQmlEvents() const;
+ QmlEvent *qmlEvent(int eventId) const;
const V8Events& getV8Events() const;
V8Event *v8Event(int eventId) const;
@@ -184,7 +184,7 @@ public:
Q_INVOKABLE qint64 traceStartTime() const;
Q_INVOKABLE qint64 traceEndTime() const;
Q_INVOKABLE qint64 traceDuration() const;
- Q_INVOKABLE qint64 declarativeMeasuredTime() const;
+ Q_INVOKABLE qint64 qmlMeasuredTime() const;
Q_INVOKABLE qint64 v8MeasuredTime() const;
void showErrorDialog(const QString &st ) const;
@@ -205,7 +205,7 @@ signals:
public slots:
void clear();
- void addDeclarativeEvent(QDeclarativeProfilerService::RangeType type,
+ void addQmlEvent(QQmlProfilerService::RangeType type,
qint64 startTime, qint64 length,
const QStringList &data,
const EventLocation &location);
@@ -222,7 +222,7 @@ public slots:
void setTraceEndTime( qint64 time );
void setTraceStartTime( qint64 time );
- void rewriteDetailsString(QDeclarativeProfilerService::RangeType eventType,
+ void rewriteDetailsString(QQmlProfilerService::RangeType eventType,
const EventLocation &location,
const QString &newString);
void finishedRewritingDetails();
@@ -3,7 +3,7 @@
** Contact: http://www.qt-project.org/
**
-** This file is part of the QtDeclarative module of the Qt Toolkit.
+** This file is part of the QtQml module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$